WFC3 Instrument Handbook for Cycle 20

| The Institute |  |  |  | HST |  |  |  | JWST |  |  |  | Community Missions |  |  |  | Data Archives |  |  |  | News and Outreach |
| HST WFC3 Instrument Design WFC3 at a glance Filters Performance Detectors Throughputs CTE Primary Ground Image Quality Anomalies Monitoring Proposing Phase I Phase II Aperture Fiducial Points Dithering Strategies Parallel SI Buffering Spectroscopy Data Analysis Post-Observation Should I Recalibrate Retrieving Data Reference Files Pixel Area Maps UVIS Flats IR Flats IR Persistence Zeropoints Full Well Depth Spectroscopy IDCTAB Testing Visiting STScI Calibration SMOV Spectroscopy Document Archive Software Tools MultiDrizzle Pipeline [WFC3 Team Members Only] |  |  |
Space Telescope Science Institute
WFC3 Instrument Handbook
help@stsci.edu
IR/F125W Description Wide J filter. Figure A.196: Integrated system throughput for F125W. Figure A.197: Point source S/N vs. V+ABν for the F125W filter, assuming high sky backgrounds and a 3×3 pixel aperture. Figure A.198: Extended source S/N vs. V+ABν for the F125W filter, assuming high sky backgrounds and a source uniformly filling a 1 arcsec2 aperture.
Copyright | Help | Printable Page